<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Shopall Pro
 * @since Shopall Pro 1.0.0
 * @return array An array of default values
 */

function shopall_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$shopall_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#010101',
		'header_tagline_color'			=> '#010101',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#fa311f',
		'colorscheme'					=> 'default',
		'theme_version'					=> 'lite-version',
		'home_layout'					=> 'first-design',

		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide-layout',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,
		'social_nav_enable'				=> true,
		'register_link'					=> '',
		'sign_in_link'					=> '',

		// excerpt options
		'long_excerpt_length'           => 25,
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'shopall-pro' ), '[the-year]', '[site-link]' ),
		'footer_banner_title'			=> esc_html__('Our Store Available in IOS & Android', 'shopall-pro'),
		'footer_banner_sub_title'		=> esc_html__('Download our app from app store or play store in your mobile and start easy shopping right away!!', 'shopall-pro'),
		'footer_social_enable'			=> true,
		'scroll_top_visible'        	=> true,
		'footer_banner_enable'		    => true,
		'footer_play_logo'		    	=> '',
		'footer_app_logo'		    	=> '',


		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'slider,service,latest_product,partner,popular_product,product_collection,recent_product,featured_product,trending_product,blog,testimonial,subscription',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'shopall-pro' ),
		'hide_date' 					=> false,
		'hide_category'					=> false,
		'hide_author'					=> false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		'nav_search_enable'				=> true,

		// topbar
		'topbar_section_enable'			=> true,
		'topbar_title'					=> esc_html__( 'WINTER CLEARANCE: Take 20% off ‘Sale of The Year’', 'shopall-pro' ),
	
		
		// slider search
		'slider_section_enable'			=> true,
		'slider_content_type'			=> 'page',
		'slider_autoplay'				=> false,
		'slider_count'					=> 3,
		'slider_sub_title_1'			=> esc_html__( 'Limited Edition', 'shopall-pro' ),
		'slider_sub_title_2'			=> esc_html__( 'Limited Edition', 'shopall-pro' ),
		'slider_sub_title_3'			=> esc_html__( 'Limited Edition', 'shopall-pro' ),
		'slider_offer_label_1'			=> esc_html__( 'New arrivals are here! Get 20% off', 'shopall-pro' ),
		'slider_offer_label_2'			=> esc_html__( 'New arrivals are here! Get 20% off', 'shopall-pro' ),
		'slider_offer_label_3'			=> esc_html__( 'New arrivals are here! Get 20% off', 'shopall-pro' ),
		'slider_btn_label_1'			=> esc_html__( 'View Collection', 'shopall-pro' ),
		'slider_btn_label_2'			=> esc_html__( 'View Collection', 'shopall-pro' ),
		'slider_btn_label_3'			=> esc_html__( 'View Collection', 'shopall-pro' ),

		//service 
		'service_section_enable'		=> true,
		'service_content_type'			=> 'page',
		'service_count'					=> 3,
		'service_column_layout'			=> 'col-3',


		//about 
		'latest_product_section_enable'		=> true,
		'latest_product_content_type'		=> 'page',

		//popular product 
		'popular_product_section_enable'		=> true,
		'popular_product_title'					=> esc_html__( 'Popular Products', 'shopall-pro' ),
		'popular_product_sub_title'				=> esc_html__( 'Add few new arrivals to your weekly lineup.', 'shopall-pro' ),
		'popular_product_tag'					=> '',


		'product_collection_section_enable'		=> true,
		'product_collection_content_type'		=> 'post',
		'product_collection_title'				=> esc_html__( 'Spring Collection 2020', 'shopall-pro' ),
		'product_collection_sub_title'			=> esc_html__( 'Latest spring collection for fashionable person like you.', 'shopall-pro' ),
		'product_collection_count'				=> 4,

		'recent_product_section_enable'		=> true,
		'recent_product_content_type'		=> 'product',
		'recent_product_count'				=> 3,
		'recent_product_title'				=> esc_html__( 'Recent Products', 'shopall-pro' ),
		'recent_product_sub_title'			=> esc_html__( 'Latest spring collection for fashionable person like you.', 'shopall-pro' ),


		'featured_product_section_enable'		=> true,
		'featured_product_content_type'			=> 'page',
		'featured_product_count'				=> 2,

		//trending_product 
		'trending_product_section_enable'				=> true,
		'trending_product_content_type'					=> 'page',
		'trending_product_count'						=> 4,
		'trending_product_section_buttom_slider_enable'	=> true,
		'trending_product_title'						=> esc_html__( 'Our Skilled Teachers', 'shopall-pro' ),

		// blog
		'blog_section_enable'			=> true,
		'blog_content_type'				=> 'page',
		'blog_count'					=> 3,
		'blog_title'					=> esc_html__( 'Our Fresh Stories', 'shopall-pro' ),
		'blog_sub_title'				=> esc_html__( 'Read our latest blog post for more information', 'shopall-pro' ),

		// testimonial
		'testimonial_section_enable'		=> true,
		'testimonial_section_link_enable'	=> false,
		'testimonial_content_type'			=> 'page',
		'testimonial_count'					=> 4,
		'testimonial_sub_title'				=> esc_html__( 'What our clients says about us!!', 'shopall-pro' ),
		'testimonial_title'					=> esc_html__( 'Latest Testimonials', 'shopall-pro' ),
		'testimonial_instagram_text'		=> esc_html__('Instagram @ ThemePalace', 'shopall-pro'),
		'testimonial_gallery_count'			=> 6,
	

		// client
		'partner_section_enable'			=> true,
		'partner_content_type'			=> 'page',
		'partner_count'					=> 6,

		// client
		'subscription_section_enable'			=> true,
		'subscription_title'					=> esc_html__( 'Newsletter Subscription', 'shopall-pro' ),
		'subscription_sub_title'				=> esc_html__( 'Sign up for updates to receive information about new arrivals, future events and specials.', 'shopall-pro' ),
		'subscription_btn_label'				=> esc_html__( 'Subscribe', 'shopall-pro' ),


	);
	for( $i = 1 ; $i <= 4 ; $i++ ){
		$shopall_pro_default_options['latest_product_banner_label_'.$i] = esc_html__('WOMEN’S FASHION', 'shopall-pro') ;
		$shopall_pro_default_options['latest_product_category_'.$i] = '';
		$shopall_pro_default_options['latest_product_banner_image_'.$i] = '';
		$shopall_pro_default_options['product_collection_btn_title_'.$i] = esc_html__('Start Shopping', 'shopall-pro');
		$shopall_pro_default_options['product_collection_btn_url_'.$i] = '';
		$shopall_pro_default_options['trending_product_title_'.$i] = esc_html__('WOMEN’S OUTFITS', 'shopall-pro');
		$shopall_pro_default_options['trending_content_type_'.$i] = 'product';

	}

	for ($i=1; $i <= 2 ; $i++) { 
		$shopall_pro_default_options['featured_product_btn_title_'.$i] = esc_html__('Start Shopping', 'shopall-pro');
		$shopall_pro_default_options['featured_product_btn_url_'.$i] = '';
	}

	$output = apply_filters( 'shopall_pro_default_theme_options', $shopall_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}