<?php
/**
 * product_collection Section options
 *
 * @package Theme Palace
 * @subpackage shopall Pro
 * @since shopall Pro 1.0.0
 */
$customizer_title = esc_html__( 'Product Collection','shopall-pro' );
$customizer_description = esc_html__( 'Product Collection Section options.', 'shopall-pro' );
if ( $options['home_layout'] == 'fourth-design' ) {
	$customizer_title = esc_html__( 'Featured Post','shopall-pro' );
	$customizer_description = esc_html__( 'Featured Post Section Options.', 'shopall-pro' );
}
if ( $options['home_layout'] == 'fifth-design' ) {
	$customizer_title = esc_html__( 'Team','shopall-pro' );
	$customizer_description = esc_html__( 'Team Section Options.', 'shopall-pro' );
}
// Add product_collection section
$wp_customize->add_section( 'shopall_pro_product_collection_section', array(
	'title'             => $customizer_title,
	'description'       => $customizer_description,
	'panel'             => 'shopall_pro_front_page_panel',
) );

// product_collection content enable control and setting
$wp_customize->add_setting( 'shopall_pro_theme_options[product_collection_section_enable]', array(
	'default'			=> 	$options['product_collection_section_enable'],
	'sanitize_callback' => 'shopall_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Shopall_Pro_Switch_Control( $wp_customize, 'shopall_pro_theme_options[product_collection_section_enable]', array(
	'label'             => $customizer_title.esc_html__( ' Section Enable', 'shopall-pro' ),
	'section'           => 'shopall_pro_product_collection_section',
	'on_off_label' 		=> shopall_pro_switch_options(),
) ) );

// product_category title setting and control
$wp_customize->add_setting( 'shopall_pro_theme_options[product_collection_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['product_collection_title'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'shopall_pro_theme_options[product_collection_title]', array(
    'label'             => esc_html__( 'Title', 'shopall-pro' ),
    'section'           => 'shopall_pro_product_collection_section',
    'active_callback'   => 'shopall_pro_is_product_collection_section_enable',
    'type'              => 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'shopall_pro_theme_options[product_collection_title]', array(
        'selector'            => '#products-collection .wrapper .section-header h2',
        'settings'            => 'shopall_pro_theme_options[product_collection_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'shopall_pro_product_collection_title_partial',
    ) );
}

// product_collection title setting and control
$wp_customize->add_setting( 'shopall_pro_theme_options[product_collection_sub_title]', array(
    'sanitize_callback' => 'wp_kses_post',
    'default'           => $options['product_collection_sub_title'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'shopall_pro_theme_options[product_collection_sub_title]', array(
    'label'             => esc_html__( 'Sub Title', 'shopall-pro' ),
    'section'           => 'shopall_pro_product_collection_section',
    'active_callback'   => 'shopall_pro_is_product_collection_section_enable',
    'type'              => 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'shopall_pro_theme_options[product_collection_sub_title]', array(
        'selector'            => '#products-collection .wrapper .section-header p',
        'settings'            => 'shopall_pro_theme_options[product_collection_sub_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'shopall_pro_product_collection_sub_title_partial',
    ) );
}
if ( $options['home_layout'] == 'fourth-design' ) {
	$wp_customize->add_setting( 'shopall_pro_theme_options[product_collection_btn_title]', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'shopall_pro_theme_options[product_collection_btn_title]', array(
		'label'           	=> esc_html__( 'Button Label', 'shopall-pro' ),
		'section'        	=> 'shopall_pro_product_collection_section',
		'active_callback' 	=> 'shopall_pro_is_product_collection_section_enable',
		'type'				=> 'text',
	) );
}

// product_collection content type control and setting
$wp_customize->add_setting( 'shopall_pro_theme_options[product_collection_content_type]', array(
	'default'          	=> $options['product_collection_content_type'],
	'sanitize_callback' => 'shopall_pro_sanitize_select',
) );

$wp_customize->add_control( 'shopall_pro_theme_options[product_collection_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'shopall-pro' ),
	'section'           => 'shopall_pro_product_collection_section',
	'type'				=> 'select',
	'active_callback' 	=> 'shopall_pro_is_product_collection_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'shopall-pro' ),
		'post' 		=> esc_html__( 'Post', 'shopall-pro' ),
		'category' 	=> esc_html__( 'Category', 'shopall-pro' ),
	),
) );

for ( $i = 1; $i <= $options['product_collection_count']; $i++ ) :
	// product_collection pages drop down chooser control and setting
	$wp_customize->add_setting( 'shopall_pro_theme_options[product_collection_content_page_' . $i . ']', array(
		'sanitize_callback' => 'shopall_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Shopall_Pro_Dropdown_Chooser( $wp_customize, 'shopall_pro_theme_options[product_collection_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'shopall-pro' ), $i ),
		'section'           => 'shopall_pro_product_collection_section',
		'choices'			=> shopall_pro_page_choices(),
		'active_callback'	=> 'shopall_pro_is_product_collection_section_content_page_enable',
	) ) );

	// product_collection posts drop down chooser control and setting
	$wp_customize->add_setting( 'shopall_pro_theme_options[product_collection_content_post_' . $i . ']', array(
		'sanitize_callback' => 'shopall_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Shopall_Pro_Dropdown_Chooser( $wp_customize, 'shopall_pro_theme_options[product_collection_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'shopall-pro' ), $i ),
		'section'           => 'shopall_pro_product_collection_section',
		'choices'			=> shopall_pro_post_choices(),
		'active_callback'	=> 'shopall_pro_is_product_collection_section_content_post_enable',
	) ) );

	
	if ( $options['home_layout'] == 'fifth-design' || $options['home_layout'] == 'fourth-design' ) {
		$wp_customize->add_setting( 'shopall_pro_theme_options[product_collection_social_' . $i. ']', array(
			'sanitize_callback' => 'esc_url_raw',
		) );

		$wp_customize->add_control( new Shopall_Pro_Multi_Input_Custom_Control( $wp_customize, 'shopall_pro_theme_options[product_collection_social_' . $i. ']', array(
			'label'             => esc_html__( 'Social Link', 'shopall-pro' ),
			'button_text'       => esc_html__( 'Add social', 'shopall-pro' ),
			'section'           => 'shopall_pro_product_collection_section',
			'active_callback' 	=> 'shopall_pro_is_product_collection_section_enable',
		) ) );

	}
	
    
	if ( ! in_array( $options['home_layout'],  array( 'fourth-design', 'fifth-design' ) ) ) {
		$wp_customize->add_setting( 'shopall_pro_theme_options[product_collection_btn_title_'.$i.']', array(
			'sanitize_callback' => 'sanitize_text_field',
			'default'			=> 'Start Shopping',
		) );

		$wp_customize->add_control( 'shopall_pro_theme_options[product_collection_btn_title_'.$i.']', array(
			'label'           	=> sprintf( esc_html__( 'Button Label %d', 'shopall-pro' ), $i ),
			'section'        	=> 'shopall_pro_product_collection_section',
			'active_callback' 	=> 'shopall_pro_is_product_collection_section_enable',
			'type'				=> 'text',
		) );


		// blog btn title setting and control
		$wp_customize->add_setting( 'shopall_pro_theme_options[product_collection_btn_url_'.$i.']', array(
			'sanitize_callback' => 'esc_url_raw',
		) );

		$wp_customize->add_control( 'shopall_pro_theme_options[product_collection_btn_url_'.$i.']', array(
			'label'           	=> sprintf( esc_html__( 'Button Url %d', 'shopall-pro' ), $i ),
			'section'        	=> 'shopall_pro_product_collection_section',
			'active_callback' 	=> 'shopall_pro_is_product_collection_section_enable',
			'type'				=> 'url',
		) );
	}
	


    $wp_customize->add_setting( 'shopall_pro_theme_options[product_collection_hr_'. $i .']', array(
        'sanitize_callback' => 'sanitize_text_field'
    ) );

    $wp_customize->add_control( new Shopall_Pro_Customize_Horizontal_Line( $wp_customize, 'shopall_pro_theme_options[product_collection_hr_'. $i .']',
        array(
            'section'           => 'shopall_pro_product_collection_section',
            'active_callback'   => 'shopall_pro_is_product_collection_section_enable',
            'type'            => 'hr'
    ) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'shopall_pro_theme_options[product_collection_content_category]', array(
	'sanitize_callback' => 'shopall_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Shopall_Pro_Dropdown_Taxonomy_Control( $wp_customize,'shopall_pro_theme_options[product_collection_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'shopall-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'shopall-pro' ),
	'section'           => 'shopall_pro_product_collection_section',
	'taxonomy'			=> 'category',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'shopall_pro_is_product_collection_section_content_category_enable'
) ) );