<?php
/**
 * recent_product Section options
 *
 * @package Theme Palace
 * @subpackage Shopall Pro
 * @since Shopall Pro 1.0.0
 */
if ( !class_exists('WooCommerce') ) {
	return;
}

// Add recent_product section
$wp_customize->add_section( 'shopall_pro_recent_product_section', array(
	'title'             => esc_html__( 'Recent Product','shopall-pro' ),
	'description'       => esc_html__( 'Recent Product Section options.', 'shopall-pro' ),
	'panel'             => 'shopall_pro_front_page_panel',
) );

// recent_product content enable control and setting
$wp_customize->add_setting( 'shopall_pro_theme_options[recent_product_section_enable]', array(
	'default'			=> 	$options['recent_product_section_enable'],
	'sanitize_callback' => 'shopall_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Shopall_Pro_Switch_Control( $wp_customize, 'shopall_pro_theme_options[recent_product_section_enable]', array(
	'label'             => esc_html__( 'Recent product Section Enable', 'shopall-pro' ),
	'section'           => 'shopall_pro_recent_product_section',
	'on_off_label' 		=> shopall_pro_switch_options(),
) ) );




// recent_product title setting and control
$wp_customize->add_setting( 'shopall_pro_theme_options[recent_product_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['recent_product_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'shopall_pro_theme_options[recent_product_title]', array(
	'label'           	=> esc_html__( 'Title', 'shopall-pro' ),
	'section'        	=> 'shopall_pro_recent_product_section',
	'active_callback' 	=> 'shopall_pro_is_recent_product_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'shopall_pro_theme_options[recent_product_title]', array(
		'selector'            => '#recent-products .section-header h2',
		'settings'            => 'shopall_pro_theme_options[recent_product_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'shopall_pro_recent_product_title_partial',
    ) );
}

// recent_product title setting and control
$wp_customize->add_setting( 'shopall_pro_theme_options[recent_product_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['recent_product_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'shopall_pro_theme_options[recent_product_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'shopall-pro' ),
	'section'        	=> 'shopall_pro_recent_product_section',
	'active_callback' 	=> 'shopall_pro_is_recent_product_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'shopall_pro_theme_options[recent_product_sub_title]', array(
		'selector'            => '#recent-products .section-header p',
		'settings'            => 'shopall_pro_theme_options[recent_product_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'shopall_pro_recent_product_sub_title_partial',
    ) );
}

$wp_customize->add_setting( 'shopall_pro_theme_options[recent_product_count]', array(
	'default'          	=> $options['recent_product_count'],
	'sanitize_callback' => 'shopall_pro_sanitize_number_range',
	'validate_callback' => 'shopall_pro_validate_recent_product_count',
) );

$wp_customize->add_control( 'shopall_pro_theme_options[recent_product_count]', array(
	'label'             => esc_html__( 'Number of Product', 'shopall-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'shopall-pro' ),
	'section'           => 'shopall_pro_recent_product_section',
	'active_callback'   => 'shopall_pro_is_recent_product_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

$wp_customize->add_setting( 'shopall_pro_theme_options[recent_product_content_type]', array(
	'default'          	=> $options['recent_product_content_type'],
	'sanitize_callback' => 'shopall_pro_sanitize_select',
) );

$wp_customize->add_control( 'shopall_pro_theme_options[recent_product_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'shopall-pro' ),
	'section'           => 'shopall_pro_recent_product_section',
	'type'				=> 'select',
	'active_callback' 	=> 'shopall_pro_is_recent_product_section_enable',
	'choices'			=> shopall_pro_recent_product_options(),
) );

for( $i = 1 ; $i <= $options['recent_product_count'] ; $i++ ){

	$wp_customize->add_setting( 'shopall_pro_theme_options[recent_product_content_page_' . $i . ']', array(
		'sanitize_callback' => 'shopall_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Shopall_Pro_Dropdown_Chooser( $wp_customize, 'shopall_pro_theme_options[recent_product_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Product %d', 'shopall-pro' ), $i ),
		'section'           => 'shopall_pro_recent_product_section',
		'choices'			=> shopall_pro_product_choices(),
		'active_callback'	=> 'shopall_pro_is_recent_product_section_content_product_enable',
	) ) );
}

$wp_customize->add_setting(  'shopall_pro_theme_options[recent_product_category]', array(
		'sanitize_callback' => 'shopall_pro_sanitize_integers',
	) ) ;

$wp_customize->add_control( new Shopall_Pro_Dropdown_Taxonomies_Control( $wp_customize,'shopall_pro_theme_options[recent_product_category]', array(
	'label'             => esc_html__( 'Select Product Categories', 'shopall-pro' ),
	'description'      	=> esc_html__( 'Note: Press CTRL and select multiple category. Latest four posts will be shown from each selected category', 'shopall-pro' ),
	'section'           => 'shopall_pro_recent_product_section',
	'taxonomy'			=> class_exists('WooCommerce') ? 'product_cat' : 'category',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'shopall_pro_is_recent_product_section_content_product_category_enable',
) ) );