<?php
/**
 * Slider Section options
 *
 * @package Theme Palace
 * @subpackage shopall Pro
 * @since shopall Pro 1.0.0
 */

// Add Slider section
$wp_customize->add_section( 'shopall_pro_slider_section', array(
	'title'             => esc_html__( 'Main Slider','shopall-pro' ),
	'description'       => esc_html__( 'Slider Section options.', 'shopall-pro' ),
	'panel'             => 'shopall_pro_front_page_panel',
) );

// Slider content enable control and setting
$wp_customize->add_setting( 'shopall_pro_theme_options[slider_section_enable]', array(
	'default'			=> 	$options['slider_section_enable'],
	'sanitize_callback' => 'shopall_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Shopall_Pro_Switch_Control( $wp_customize, 'shopall_pro_theme_options[slider_section_enable]', array(
	'label'             => esc_html__( 'Slider Section Enable', 'shopall-pro' ),
	'section'           => 'shopall_pro_slider_section',
	'on_off_label' 		=> shopall_pro_switch_options(),
) ) );

// Slider content enable control and setting
$wp_customize->add_setting( 'shopall_pro_theme_options[slider_autoplay]', array(
	'default'			=> 	$options['slider_autoplay'],
	'sanitize_callback' => 'shopall_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Shopall_Pro_Switch_Control( $wp_customize, 'shopall_pro_theme_options[slider_autoplay]', array(
	'label'             => esc_html__( 'Auto Play Enable', 'shopall-pro' ),
	'section'           => 'shopall_pro_slider_section',
	'on_off_label' 		=> shopall_pro_switch_options(),
	'active_callback' 	=> 'shopall_pro_is_slider_section_enable',
) ) );


// Event social icons number control and setting
$wp_customize->add_setting( 'shopall_pro_theme_options[slider_count]', array(
	'default'          	=> $options['slider_count'],
	'sanitize_callback' => 'shopall_pro_sanitize_number_range',
	'validate_callback' => 'shopall_pro_validate_slider_count',
) );

$wp_customize->add_control( 'shopall_pro_theme_options[slider_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'shopall-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'shopall-pro' ),
	'section'           => 'shopall_pro_slider_section',
	'active_callback'   => 'shopall_pro_is_slider_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );
if ( $options['home_layout'] == 'fourth-design' || $options['home_layout'] == 'fifth-design' || $options['home_layout'] == 'third-design' ) { 
	if ( $options['home_layout'] == 'fifth-design' ) {
		for( $i=1 ; $i<= $options['slider_count'] ; $i++ ) {
			$wp_customize->add_setting( 'shopall_pro_theme_options[slider_sub_title_'.$i.']', array(
				'sanitize_callback' => 'sanitize_text_field',
				'default'			=> $options['slider_sub_title_'.$i],
			) );

			$wp_customize->add_control( 'shopall_pro_theme_options[slider_sub_title_'.$i.']', array(
				'label'           	=> sprintf( esc_html__( 'Slider Sub Title %d', 'shopall-pro' ), $i ),
				'section'        	=> 'shopall_pro_slider_section',
				'active_callback' 	=> 'shopall_pro_is_slider_section_enable',
				'type'				=> 'text',
			) );
		}
	}
	$wp_customize->add_setting( 'shopall_pro_theme_options[slider_btn_label]', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'shopall_pro_theme_options[slider_btn_label]', array(
		'label'           	=> esc_html__( 'Slider Btn Title', 'shopall-pro' ),
		'section'        	=> 'shopall_pro_slider_section',
		'active_callback' 	=> 'shopall_pro_is_slider_section_enable',
		'type'				=> 'text',
	) );
}

if ( ! in_array( $options['home_layout'],  array( 'fourth-design', 'fifth-design', 'third-design' ) ) ) {
	for( $i=1 ; $i<= $options['slider_count'] ; $i++ ) {
		$wp_customize->add_setting( 'shopall_pro_theme_options[slider_sub_title_'.$i.']', array(
			'sanitize_callback' => 'sanitize_text_field',
			'default'			=> $options['slider_sub_title_'.$i],
		) );

		$wp_customize->add_control( 'shopall_pro_theme_options[slider_sub_title_'.$i.']', array(
			'label'           	=> sprintf( esc_html__( 'Slider Sub Title %d', 'shopall-pro' ), $i ),
			'section'        	=> 'shopall_pro_slider_section',
			'active_callback' 	=> 'shopall_pro_is_slider_section_enable',
			'type'				=> 'text',
		) );
	}

	$wp_customize->add_setting( 'shopall_pro_theme_options[slider_hr_3]', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Shopall_Pro_Customize_Horizontal_Line( $wp_customize, 'shopall_pro_theme_options[slider_hr_3]',
		array(
			'section'         => 'shopall_pro_slider_section',
			'active_callback' => 'shopall_pro_is_slider_section_enable',
			'type'			  => 'hr'
	) ) );

	for( $i=1 ; $i<= $options['slider_count'] ; $i++ ) {
		

		$wp_customize->add_setting( 'shopall_pro_theme_options[slider_offer_label_'.$i.']', array(
			'sanitize_callback' => 'wp_kses_post',
			'default'			=> $options['slider_offer_label_'.$i],
		) );

		$wp_customize->add_control( 'shopall_pro_theme_options[slider_offer_label_'.$i.']', array(
			'label'           	=> sprintf( esc_html__( 'Slider Offer Label %d', 'shopall-pro' ), $i ),
			'section'        	=> 'shopall_pro_slider_section',
			'active_callback' 	=> 'shopall_pro_is_slider_section_enable',
			'type'				=> 'text',
		) );

	}

	$wp_customize->add_setting( 'shopall_pro_theme_options[slider_hr_4]', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Shopall_Pro_Customize_Horizontal_Line( $wp_customize, 'shopall_pro_theme_options[slider_hr_4]',
		array(
			'section'         => 'shopall_pro_slider_section',
			'active_callback' => 'shopall_pro_is_slider_section_enable',
			'type'			  => 'hr'
	) ) );

	for( $i=1 ; $i<= $options['slider_count'] ; $i++ ) {

		$wp_customize->add_setting( 'shopall_pro_theme_options[slider_btn_label_'.$i.']', array(
			'sanitize_callback' => 'sanitize_text_field',
			'default'			=> $options['slider_btn_label_'.$i],
		) );

		$wp_customize->add_control( 'shopall_pro_theme_options[slider_btn_label_'.$i.']', array(
			'label'           	=> sprintf( esc_html__( 'Slider Button Lable %d', 'shopall-pro' ), $i ),
			'section'        	=> 'shopall_pro_slider_section',
			'active_callback' 	=> 'shopall_pro_is_slider_section_enable',
			'type'				=> 'text',
		) );
	}

	$wp_customize->add_setting( 'shopall_pro_theme_options[slider_hr_1]', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Shopall_Pro_Customize_Horizontal_Line( $wp_customize, 'shopall_pro_theme_options[slider_hr_1]',
		array(
			'section'         => 'shopall_pro_slider_section',
			'active_callback' => 'shopall_pro_is_slider_section_enable',
			'type'			  => 'hr'
	) ) );

	for( $i=1 ; $i<= $options['slider_count'] ; $i++ ) {

		$wp_customize->add_setting( 'shopall_pro_theme_options[slider_btn_url_'.$i.']', array(
			'sanitize_callback' => 'esc_url_raw',
		) );

		$wp_customize->add_control( 'shopall_pro_theme_options[slider_btn_url_'.$i.']', array(
			'label'           	=> sprintf( esc_html__( 'Slider Button Link %d', 'shopall-pro' ), $i ),
			'section'        	=> 'shopall_pro_slider_section',
			'active_callback' 	=> 'shopall_pro_is_slider_section_enable',
			'type'				=> 'url',
		) );
	}

	$wp_customize->add_setting( 'shopall_pro_theme_options[slider_hr_2]', array(
		'sanitize_callback' => 'sanitize_text_field'

	) );

	$wp_customize->add_control( new Shopall_Pro_Customize_Horizontal_Line( $wp_customize, 'shopall_pro_theme_options[slider_hr_2]',
		array(
			'section'         => 'shopall_pro_slider_section',
			'active_callback' => 'shopall_pro_is_slider_section_enable',
			'type'			  => 'hr'
	) ) );
}



// Slider content type control and setting
$wp_customize->add_setting( 'shopall_pro_theme_options[slider_content_type]', array(
	'default'          	=> $options['slider_content_type'],
	'sanitize_callback' => 'shopall_pro_sanitize_select',
) );

$wp_customize->add_control( 'shopall_pro_theme_options[slider_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'shopall-pro' ),
	'section'           => 'shopall_pro_slider_section',
	'type'				=> 'select',
	'active_callback' 	=> 'shopall_pro_is_slider_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'shopall-pro' ),
		'post' 		=> esc_html__( 'Post', 'shopall-pro' ),
		'category' 	=> esc_html__( 'Category', 'shopall-pro' ),
	),
) );

for ( $i = 1; $i <= $options['slider_count']; $i++ ) :
	// slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'shopall_pro_theme_options[slider_content_page_' . $i . ']', array(
		'sanitize_callback' => 'shopall_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Shopall_Pro_Dropdown_Chooser( $wp_customize, 'shopall_pro_theme_options[slider_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'shopall-pro' ), $i ),
		'section'           => 'shopall_pro_slider_section',
		'choices'			=> shopall_pro_page_choices(),
		'active_callback'	=> 'shopall_pro_is_slider_section_content_page_enable',
	) ) );

	// slider posts drop down chooser control and setting
	$wp_customize->add_setting( 'shopall_pro_theme_options[slider_content_post_' . $i . ']', array(
		'sanitize_callback' => 'shopall_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Shopall_Pro_Dropdown_Chooser( $wp_customize, 'shopall_pro_theme_options[slider_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'shopall-pro' ), $i ),
		'section'           => 'shopall_pro_slider_section',
		'choices'			=> shopall_pro_post_choices(),
		'active_callback'	=> 'shopall_pro_is_slider_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'shopall_pro_theme_options[slider_content_category]', array(
	'sanitize_callback' => 'shopall_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Shopall_Pro_Dropdown_Taxonomy_Control( $wp_customize,'shopall_pro_theme_options[slider_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'shopall-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'shopall-pro' ),
	'section'           => 'shopall_pro_slider_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'shopall_pro_is_slider_section_content_category_enable'
) ) );
