<?php
/**
 * Testimonial Section options
 *
 * @package Theme Palace
 * @subpackage Shopall Pro
 * @since Shopall Pro 1.0.0
 */

// Add Testimonial section
$wp_customize->add_section( 'shopall_pro_testimonial_section', array(
	'title'             => esc_html__( 'Testimonial','shopall-pro' ),
	'description'       => esc_html__( 'Testimonial Section options.', 'shopall-pro' ),
	'panel'             => 'shopall_pro_front_page_panel',
) );

// Testimonial content enable control and setting
$wp_customize->add_setting( 'shopall_pro_theme_options[testimonial_section_enable]', array(
	'default'			=> 	$options['testimonial_section_enable'],
	'sanitize_callback' => 'shopall_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Shopall_Pro_Switch_Control( $wp_customize, 'shopall_pro_theme_options[testimonial_section_enable]', array(
	'label'             => esc_html__( 'Testimonial Section Enable', 'shopall-pro' ),
	'section'           => 'shopall_pro_testimonial_section',
	'on_off_label' 		=> shopall_pro_switch_options(),
) ) );

// testimonial title setting and control
$wp_customize->add_setting( 'shopall_pro_theme_options[testimonial_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['testimonial_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'shopall_pro_theme_options[testimonial_title]', array(
	'label'           	=> esc_html__( 'Title', 'shopall-pro' ),
	'section'        	=> 'shopall_pro_testimonial_section',
	'active_callback' 	=> 'shopall_pro_is_testimonial_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'shopall_pro_theme_options[testimonial_title]', array(
		'selector'            => '#testimonial-section .section-header h2',
		'settings'            => 'shopall_pro_theme_options[testimonial_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'shopall_pro_testimonial_title_partial',
    ) );
}

$wp_customize->add_setting( 'shopall_pro_theme_options[testimonial_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['testimonial_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'shopall_pro_theme_options[testimonial_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'shopall-pro' ),
	'section'        	=> 'shopall_pro_testimonial_section',
	'active_callback' 	=> 'shopall_pro_is_testimonial_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'shopall_pro_theme_options[testimonial_sub_title]', array(
		'selector'            => '#testimonial-section .section-header p',
		'settings'            => 'shopall_pro_theme_options[testimonial_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'shopall_pro_testimonial_sub_title_partial',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'shopall_pro_theme_options[testimonial_count]', array(
	'default'          	=> $options['testimonial_count'],
	'sanitize_callback' => 'shopall_pro_sanitize_number_range',
	'validate_callback' => 'shopall_pro_validate_testimonial_count',
) );

$wp_customize->add_control( 'shopall_pro_theme_options[testimonial_count]', array(
	'label'             => esc_html__( 'Number of Testimonials', 'shopall-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'shopall-pro' ),
	'section'           => 'shopall_pro_testimonial_section',
	'active_callback'   => 'shopall_pro_is_testimonial_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Testimonial content type control and setting
$wp_customize->add_setting( 'shopall_pro_theme_options[testimonial_content_type]', array(
	'default'          	=> $options['testimonial_content_type'],
	'sanitize_callback' => 'shopall_pro_sanitize_select',
) );

$wp_customize->add_control( 'shopall_pro_theme_options[testimonial_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'shopall-pro' ),
	'section'           => 'shopall_pro_testimonial_section',
	'type'				=> 'select',
	'active_callback' 	=> 'shopall_pro_is_testimonial_section_enable',
	'choices'			=> shopall_pro_testimonial_content_type(),
) );



for ( $i = 1; $i <= $options['testimonial_count']; $i++ ) :
	// testimonial pages drop down chooser control and setting
	$wp_customize->add_setting( 'shopall_pro_theme_options[testimonial_content_page_' . $i . ']', array(
		'sanitize_callback' => 'shopall_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Shopall_Pro_Dropdown_Chooser( $wp_customize, 'shopall_pro_theme_options[testimonial_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'shopall-pro' ), $i ),
		'section'           => 'shopall_pro_testimonial_section',
		'choices'			=> shopall_pro_page_choices(),
		'active_callback'	=> 'shopall_pro_is_testimonial_section_content_page_enable',
	) ) );


	// testimonial posts drop down chooser control and setting
	$wp_customize->add_setting( 'shopall_pro_theme_options[testimonial_content_post_' . $i . ']', array(
		'sanitize_callback' => 'shopall_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Shopall_Pro_Dropdown_Chooser( $wp_customize, 'shopall_pro_theme_options[testimonial_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'shopall-pro' ), $i ),
		'section'           => 'shopall_pro_testimonial_section',
		'choices'			=> shopall_pro_post_choices(),
		'active_callback'	=> 'shopall_pro_is_testimonial_section_content_post_enable',
	) ) );

	// testimonial title setting and control
	$wp_customize->add_setting( 'shopall_pro_theme_options[testimonial_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'shopall_pro_theme_options[testimonial_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Title %d', 'shopall-pro' ), $i ),
		'section'        	=> 'shopall_pro_testimonial_section',
		'active_callback' 	=> 'shopall_pro_is_testimonial_section_content_custom_enable',
		'type'				=> 'text',
	) );


	$options['testimonial_position_'.$i] = isset($options['testimonial_position_'.$i]) ? $options['testimonial_position_'.$i] : esc_html__('Happy Client', 'shopall-pro');
	// testimonial position setting and control
	$wp_customize->add_setting( 'shopall_pro_theme_options[testimonial_position_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['testimonial_position_'.$i],
	) );

	$wp_customize->add_control( 'shopall_pro_theme_options[testimonial_position_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'position %d', 'shopall-pro' ), $i ),
		'section'        	=> 'shopall_pro_testimonial_section',
		'active_callback' 	=> 'shopall_pro_is_testimonial_section_content_position_enable',
		'type'				=> 'text',
	) );

	// testimonial description setting and control
	$wp_customize->add_setting( 'shopall_pro_theme_options[testimonial_description_' . $i . ']', array(
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( 'shopall_pro_theme_options[testimonial_description_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Description %d', 'shopall-pro' ), $i ),
		'section'        	=> 'shopall_pro_testimonial_section',
		'active_callback' 	=> 'shopall_pro_is_testimonial_section_content_custom_enable',
		'type'				=> 'textarea',
	) );

	// testimonial image setting and control.
	$wp_customize->add_setting( 'shopall_pro_theme_options[testimonial_image_' . $i . ']', array(
		'sanitize_callback' => 'shopall_pro_sanitize_image'
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'shopall_pro_theme_options[testimonial_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Image %d', 'shopall-pro' ), $i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'shopall-pro' ), 200, 200 ),
			'section'     		=> 'shopall_pro_testimonial_section',
			'active_callback'	=> 'shopall_pro_is_testimonial_section_content_custom_enable',
	) ) );

	// testimonial position setting and control
	$wp_customize->add_setting( 'shopall_pro_theme_options[testimonial_link_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'shopall_pro_theme_options[testimonial_link_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'URL Link %d', 'shopall-pro' ), $i ),
		'section'        	=> 'shopall_pro_testimonial_section',
		'active_callback' 	=> 'shopall_pro_is_testimonial_section_content_custom_enable',
		'type'				=> 'url',
	) );

	// testimonial hr setting and control
	$wp_customize->add_setting( 'shopall_pro_theme_options[testimonial_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Shopall_Pro_Customize_Horizontal_Line( $wp_customize, 'shopall_pro_theme_options[testimonial_hr_'. $i .']',
		array(
			'section'         => 'shopall_pro_testimonial_section',
			'active_callback' => 'shopall_pro_is_testimonial_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );
endfor;


$wp_customize->add_setting( 'shopall_pro_theme_options[testimonial_instagram_text]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['testimonial_instagram_text'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'shopall_pro_theme_options[testimonial_instagram_text]', array(
	'label'           	=> esc_html__( 'Instagram Label', 'shopall-pro' ),
	'section'        	=> 'shopall_pro_testimonial_section',
	'active_callback' 	=> 'shopall_pro_is_testimonial_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'shopall_pro_theme_options[testimonial_instagram_text]', array(
		'selector'            => '#testimonial-section .tp-instagram h3',
		'settings'            => 'shopall_pro_theme_options[testimonial_instagram_text]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'shopall_pro_testimonial_instagram_text_partial',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'shopall_pro_theme_options[testimonial_gallery_count]', array(
	'default'          	=> $options['testimonial_gallery_count'],
	'sanitize_callback' => 'shopall_pro_sanitize_number_range',
	'validate_callback' => 'shopall_pro_validate_testimonial_gallery_acount',
) );

$wp_customize->add_control( 'shopall_pro_theme_options[testimonial_gallery_count]', array(
	'label'             => esc_html__( 'Number of Testimonials', 'shopall-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'shopall-pro' ),
	'section'           => 'shopall_pro_testimonial_section',
	'active_callback'   => 'shopall_pro_is_testimonial_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ($i=1; $i <= $options['testimonial_gallery_count'] ; $i++) { 
	$wp_customize->add_setting( 'shopall_pro_theme_options[testimonial_image_'.$i.']', array(
	    'sanitize_callback' => 'shopall_pro_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'shopall_pro_theme_options[testimonial_image_'.$i.']',
	        array(
	        'label'             => esc_html__( 'Select Images ', 'shopall-pro' ).$i,
	        'section'           => 'shopall_pro_testimonial_section',
	        'active_callback'   => 'shopall_pro_is_testimonial_section_enable',
	) ) );
}

