<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Shopall Pro
 * @since Shopall Pro 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */

function shopall_pro_product_choices() {
    $full_product_list = array();
    $product_id = array();
    $loop = new WP_Query(array('post_type' => array('product', 'product_variation'), 'posts_per_page' => -1));
    while ($loop->have_posts()) : $loop->the_post();
        $product_id[] = get_the_id();
    endwhile;
    wp_reset_postdata();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'shopall-pro' );
    foreach ( $product_id  as $id ) {
        $choices[ $id ] = get_the_title( $id );
    }
    return  $choices;
}

function shopall_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'shopall-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function shopall_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'shopall-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}



if ( ! function_exists( 'shopall_pro_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function shopall_pro_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'shopall-pro' ),
            'header-font-1'   => esc_html__( 'Rajdhani', 'shopall-pro' ),
            'header-font-2'   => esc_html__( 'Cherry Swash', 'shopall-pro' ),
            'header-font-3'   => esc_html__( 'Philosopher', 'shopall-pro' ),
            'header-font-4'   => esc_html__( 'Slabo 27px', 'shopall-pro' ),
            'header-font-5'   => esc_html__( 'Dosis', 'shopall-pro' ),
        );

        $output = apply_filters( 'shopall_pro_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'shopall_pro_body_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function shopall_pro_body_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'shopall-pro' ),
            'body-font-1'     => esc_html__( 'News Cycle', 'shopall-pro' ),
            'body-font-2'     => esc_html__( 'Pontano Sans', 'shopall-pro' ),
            'body-font-3'     => esc_html__( 'Gudea', 'shopall-pro' ),
            'body-font-4'     => esc_html__( 'Quattrocento', 'shopall-pro' ),
            'body-font-5'     => esc_html__( 'Khand', 'shopall-pro' ),
        );

        $output = apply_filters( 'shopall_pro_body_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'shopall_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function shopall_pro_selected_sidebar() {
        $shopall_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'shopall-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'shopall-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'shopall-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'shopall-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'shopall-pro' ),
        );

        $output = apply_filters( 'shopall_pro_selected_sidebar', $shopall_pro_selected_sidebar );

        return $output;
    }
endif;

if ( ! function_exists( 'shopall_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function shopall_pro_site_layout() {
        $shopall_pro_site_layout = array(
            'wide-layout'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
            'frame-layout' => get_template_directory_uri() . '/assets/images/framed.png',
        );

        $output = apply_filters( 'shopall_pro_site_layout', $shopall_pro_site_layout );
        return $output;
    }
endif;


if ( ! function_exists( 'shopall_pro_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function shopall_pro_global_sidebar_position() {
        $shopall_pro_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'shopall_pro_global_sidebar_position', $shopall_pro_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'shopall_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function shopall_pro_sidebar_position() {
        $shopall_pro_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
            'no-sidebar-content'   => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'shopall_pro_sidebar_position', $shopall_pro_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'shopall_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function shopall_pro_pagination_options() {
        $shopall_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'shopall-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'shopall-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'shopall-pro' ),
        );

        $output = apply_filters( 'shopall_pro_pagination_options', $shopall_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'shopall_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function shopall_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'shopall-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'shopall-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'shopall-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'shopall-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'shopall-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'shopall-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'shopall-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'shopall-pro' ),
        );
        return apply_filters( 'shopall_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'shopall_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function shopall_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'shopall-pro' ),
            'off'       => esc_html__( 'Disable', 'shopall-pro' )
        );
        return apply_filters( 'shopall_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'shopall_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function shopall_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'shopall-pro' ),
            'off'       => esc_html__( 'No', 'shopall-pro' )
        );
        return apply_filters( 'shopall_pro_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'shopall_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function shopall_pro_sortable_sections() {
        $sections = array(
            'slider'                => esc_html__( 'Main Slider', 'shopall-pro' ),
            'service'               => esc_html__( 'Service Section', 'shopall-pro' ),
            'latest_product'        => esc_html__( 'Latest Product Section', 'shopall-pro' ),
            'partner'               => esc_html__( 'partner Section', 'shopall-pro' ),
            'popular_product'       => esc_html__( 'Popula Product Section', 'shopall-pro' ),
            'product_collection'    => esc_html__( 'Product Collection Section', 'shopall-pro' ),
            'recent_product'        => esc_html__( 'Recent Product Section', 'shopall-pro' ),
            'counter'               => esc_html__( 'Counter Section', 'shopall-pro' ),
            'featured_product'      => esc_html__( 'Featured Product Section', 'shopall-pro' ),
            'trending_product'      => esc_html__( 'Trending Product Section', 'shopall-pro' ),
            'blog'                  => esc_html__( 'Blog Section', 'shopall-pro' ),
            'testimonial'           => esc_html__( 'Testimonial Section', 'shopall-pro' ),
            'subscription'          => esc_html__( 'Subscription Section', 'shopall-pro' ),
        );
        return apply_filters( 'shopall_pro_sortable_sections', $sections );
    }
endif;



if ( ! function_exists( 'shopall_pro_testimonial_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function shopall_pro_testimonial_content_type() {
        $shopall_pro_testimonial_content_type = array(
            'page'      => esc_html__( 'Page', 'shopall-pro' ),
            'post'      => esc_html__( 'Post', 'shopall-pro' ),
            'custom'  => esc_html__( 'Custom', 'shopall-pro' ),
        );

        $output = apply_filters( 'shopall_pro_testimonial_content_type', $shopall_pro_testimonial_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'shopall_pro_latest_product' ) ) :
    /**
     * List of latest product
     * @return array List of latest product.
     */
    function shopall_pro_latest_product() {
        $arr = array(
            'page'          => esc_html__( 'Page', 'shopall-pro' ),
            'post'          => esc_html__( 'Post', 'shopall-pro' ),
            'category'      => esc_html__( 'Post Category', 'shopall-pro' ),
        );
        if ( class_exists( 'WooCommerce' ) ) {
            $arr = array_merge( $arr, 
                array( 
                    'product'           => esc_html__( 'Product', 'shopall-pro' ), 
                    'product-category'  => esc_html__( 'Product Category', 'shopall-pro' ), 
                    'latest-product'    => esc_html__( 'Latest Products', 'shopall-pro' ), 
                    ) 
                );
        }

        return apply_filters( 'shopall_pro_latest_options', $arr );
    }
endif;

if ( ! function_exists( 'shopall_pro_recent_product_options' ) ) :
    /**
     * List of recent_product options
     * @return array List of recent_product options.
     */
    function shopall_pro_recent_product_options() {
    
        if ( class_exists( 'WooCommerce' ) ) {
                $arr = array(
                'product'           => esc_html__( 'Product', 'shopall-pro' ),
                'product_cat'       => esc_html__( 'Product Category', 'shopall-pro' ),
                'recent_product'    => esc_html__( 'Recent Product', 'shopall-pro' ),
            );
        }

        return apply_filters( 'shopall_pro_recent_product_options', $arr );
    }
endif;