<?php
/**
 * partner section
 *
 * This is the template for the content of partner section
 *
 * @package Theme Palace
 * @subpackage Shopall Pro
 * @since Shopall Pro 1.0.0
 */
if ( ! function_exists( 'shopall_pro_add_partner_section' ) ) :
    /**
    * Add partner section
    *
    *@since shopall_pro 1.0.0
    */
    function shopall_pro_add_partner_section() {
    	$options = shopall_pro_get_theme_options();
        // Check if partner is enabled on frontpage
        $partner_enable = apply_filters( 'shopall_pro_section_status', true, 'partner_section_enable' );

        if ( true !== $partner_enable ) {
            return false;
        }
        // Get partner section details
        $section_details = array();
        $section_details = apply_filters( 'shopall_pro_filter_partner_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render partner section now.
        shopall_pro_render_partner_section( $section_details );
    }
endif;

if ( ! function_exists( 'shopall_pro_get_partner_section_details' ) ) :
    /**
    * partner section details.
    *
    * @since shopall_pro 1.0.0
    * @param array $input partner section details.
    */
    function shopall_pro_get_partner_section_details( $input ) {
        $options = shopall_pro_get_theme_options();

        // Content type.
        $partner_content_type  = $options['partner_content_type'];
        $partner_count = ! empty( $options['partner_count'] ) ? $options['partner_count'] : 4;
        
        $content = array();
        switch ( $partner_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $partner_count; $i++ ) {
                    if ( ! empty( $options['partner_content_page_' . $i] ) )
                        $page_ids[] = $options['partner_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $partner_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $partner_count; $i++ ) {
                    if ( ! empty( $options['partner_content_post_' . $i] ) )
                        $post_ids[] = $options['partner_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $partner_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['partner_content_category'] ) ? $options['partner_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $partner_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'custom':
                for ( $i=1; $i <= $partner_count; $i++ ) { 
                    $custom['image']    = ( empty( $options['partner_image_' . $i ] ) ) ? '' : $options['partner_image_' . $i ];                
                    $custom['url']      = ( empty( $options['partner_url_' . $i ] ) ) ? '' : $options['partner_url_' . $i ];                         
                    array_push( $content, $custom );
                }
            break;

            default:
            break;
        }

        // Run The Loop.
        if ( 'custom' !== $options['partner_content_type'] ) {
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['url']       = get_the_permalink( );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';
                    // Push to the main array.
                    array_push( $content, $page_post );

                endwhile;
            endif;
            wp_reset_postdata();
        }
                    
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// partner section content details.
add_filter( 'shopall_pro_filter_partner_section_details', 'shopall_pro_get_partner_section_details' );


if ( ! function_exists( 'shopall_pro_render_partner_section' ) ) :
  /**
   * Start partner section
   *
   * @return string partner content
   * @since shopall_pro 1.0.0
   *
   */
   function shopall_pro_render_partner_section( $content_details = array() ) {
        $options    = shopall_pro_get_theme_options();
        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="our-partners" class="relative page-section same-background">
            <div class="wrapper">
                <div class="col-<?php echo $options['home_layout'] == 'fifth-design' ? 4 : 6 ; ?>">
                    <?php $i = 1 ; foreach ( $content_details as $content ): 
                         $image = $content['image'] == '' ? get_template_directory_uri().'/assets/uploads/no-featured-image-590x650.jpg' : $content['image'] ;
                    ?>
                        <article>
                            <a href="<?php echo esc_url( $content['url'] ); ?>">
                                <img src="<?php echo esc_url( $image ); ?>" alt="<?php echo esc_attr( $i ) ; ?>">
                            </a>
                        </article>
                    <?php $i++; endforeach ?>
                </div><!-- .col-4 -->
            </div><!-- .wrapper -->
        </div>
    <?php }
endif;
