<?php
/**
 * Slider section
 *
 * This is the template for the content of slider section
 *
 * @package Theme Palace
 * @subpackage Shopall Pro
 * @since Shopall Pro 1.0.0
 */
if ( ! function_exists( 'shopall_pro_add_slider_section' ) ) :
    /**
    * Add slider section
    *
    *@since Shopall Pro 1.0.0
    */
    function shopall_pro_add_slider_section() {
    	$options = shopall_pro_get_theme_options();
        // Check if slider is enabled on frontpage
        $slider_enable = apply_filters( 'shopall_pro_section_status', true, 'slider_section_enable' );

        if ( true !== $slider_enable ) {
            return false;
        }
        // Get slider section details
        $section_details = array();
        $section_details = apply_filters( 'shopall_pro_filter_slider_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render slider section now.
        shopall_pro_render_slider_section( $section_details );
    }
endif;

if ( ! function_exists( 'shopall_pro_get_slider_section_details' ) ) :
    /**
    * slider section details.
    *
    * @since Shopall Pro 1.0.0
    * @param array $input slider section details.
    */
    function shopall_pro_get_slider_section_details( $input ) {
        $options = shopall_pro_get_theme_options();

        // Content type.
        $slider_content_type  = $options['slider_content_type'];
        $slider_count = ! empty( $options['slider_count'] ) ? $options['slider_count'] : 3;
        
        $content = array();
        switch ( $slider_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $slider_count; $i++ ) {
                    if ( ! empty( $options['slider_content_page_' . $i] ) )
                        $page_ids[] = $options['slider_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $slider_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $slider_count; $i++ ) {
                    if ( ! empty( $options['slider_content_post_' . $i] ) )
                        $post_ids[] = $options['slider_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $slider_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['slider_content_category'] ) ? $options['slider_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $slider_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = shopall_pro_trim_content( 30 );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// slider section content details.
add_filter( 'shopall_pro_filter_slider_section_details', 'shopall_pro_get_slider_section_details' );


if ( ! function_exists( 'shopall_pro_render_slider_section' ) ) :
  /**
   * Start slider section
   *
   * @return string slider content
   * @since Shopall Pro 1.0.0
   *
   */
   function shopall_pro_render_slider_section( $content_details = array() ) {
        $options = shopall_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="featured-slider" data-slick='{"slidesToShow": <?php echo $options['home_layout'] == 'third-design' ? 3 : 1 ; ?>, "slidesToScroll": 1, "infinite": true, "speed": 800, "dots": true, "arrows": true, "autoplay": true, "draggable": true, "fade": false }'>    
            <?php $i = 1 ; foreach ($content_details as $content): 
                $image = $content['image'] == '' ? get_template_directory_uri().'/assets/uploads/no-featured-image-590x650.jpg' : $content['image'] ;
            ?>
                <article style="background-image:url('<?php echo esc_url( $image ); ?>');">
                    <?php if ( $options['home_layout'] == 'fourth-design' ): ?>
                        <div class="overlay" ></div>
                    <?php endif ?>
                    
                    <div class="wrapper">
                        <div class="featured-content-wrapper">
                            <header class="entry-header">
                                <?php if ( ! in_array( $options['home_layout'],  array( 'fourth-design', 'third-design' ) ) ): ?>
                                    <p class="subtitle" > <?php echo esc_html( $options['slider_sub_title_'.$i] ) ; ?></p>
                                <?php endif ?>
                                <?php if ( $options['home_layout'] == 'fourth-design' || $options['home_layout'] == 'third-design' ): ?>
                                    <?php the_category( '', '', $content['id'] ) ?>
                                <?php endif ?>
                                <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>" ><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>

                            <div class="entry-content">
                                <p ><?php echo wp_kses_post( $options['slider_offer_label_'.$i] ); ?></p>
                            </div><!-- .entry-content-->
                            <?php if ( ! in_array( $options['home_layout'],  array( 'fourth-design', 'fifth-design', 'third-design' ) ) ): ?>
                                <?php if ( !empty( $options['slider_btn_url_'.$i] ) && !empty( $options['slider_btn_label_'.$i] ) ) : ?>
                                    <div class="read-more">
                                        <a href="<?php echo esc_url($options['slider_btn_url_'.$i]); ?>" class="btn" > <?php echo esc_html( $options['slider_btn_label_'.$i] ) ?></a>
                                    </div><!-- .read-more -->
                                <?php endif ?>     
                            <?php endif ?>
                            <?php if ( $options['home_layout'] == 'fourth-design' || $options['home_layout'] == 'fifth-design' || $options['home_layout'] == 'third-design' ): ?>
                                <?php if ( !empty( $options['slider_btn_label'] ) ) : ?>
                                    <div class="read-more">
                                        <a href="<?php echo esc_url($content['url']); ?>" class="btn" > <?php echo esc_html( $options['slider_btn_label'] ) ?></a>
                                    </div><!-- .read-more -->
                                <?php endif ?>     
                            <?php endif ?>                       
                        </div><!-- .featured-content-wrapper -->
                    </div><!-- .wrapper -->
                </article>
            <?php $i++; endforeach ; ?>
        </div><!-- #featured-slider -->
                       
    <?php }
endif;